==> zio-aws-sagemaker_2.12-5.17.123.1-sources.jar: zio/aws/sagemaker/model/ListSubscribedWorkteamsResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListSubscribedWorkteamsResponse(
    subscribedWorkteams: Iterable[zio.aws.sagemaker.model.SubscribedWorkteam],
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse = {
    import ListSubscribedWorkteamsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
      .builder()
      .subscribedWorkteams(subscribedWorkteams.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse.ReadOnly =
    zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse
      .wrap(buildAwsValue())
}
object ListSubscribedWorkteamsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse =
      zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse(
        subscribedWorkteams.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def subscribedWorkteams
        : List[zio.aws.sagemaker.model.SubscribedWorkteam.ReadOnly]
    def nextToken: Option[NextToken]
    def getSubscribedWorkteams: ZIO[Any, Nothing, List[
      zio.aws.sagemaker.model.SubscribedWorkteam.ReadOnly
    ]] = ZIO.succeed(subscribedWorkteams)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
  ) extends zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse.ReadOnly {
    override val subscribedWorkteams
        : List[zio.aws.sagemaker.model.SubscribedWorkteam.ReadOnly] = impl
      .subscribedWorkteams()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.SubscribedWorkteam.wrap(item)
      }
      .toList
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
  ): zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/ListSubscribedWorkteamsResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListSubscribedWorkteamsResponse(
    subscribedWorkteams: Iterable[zio.aws.sagemaker.model.SubscribedWorkteam],
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse = {
    import ListSubscribedWorkteamsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
      .builder()
      .subscribedWorkteams(subscribedWorkteams.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse.ReadOnly =
    zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse
      .wrap(buildAwsValue())
}
object ListSubscribedWorkteamsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse =
      zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse(
        subscribedWorkteams.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def subscribedWorkteams
        : List[zio.aws.sagemaker.model.SubscribedWorkteam.ReadOnly]
    def nextToken: Optional[NextToken]
    def getSubscribedWorkteams: ZIO[Any, Nothing, List[
      zio.aws.sagemaker.model.SubscribedWorkteam.ReadOnly
    ]] = ZIO.succeed(subscribedWorkteams)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
  ) extends zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse.ReadOnly {
    override val subscribedWorkteams
        : List[zio.aws.sagemaker.model.SubscribedWorkteam.ReadOnly] = impl
      .subscribedWorkteams()
      .asScala
      .map { item =>
        zio.aws.sagemaker.model.SubscribedWorkteam.wrap(item)
      }
      .toList
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListSubscribedWorkteamsResponse
  ): zio.aws.sagemaker.model.ListSubscribedWorkteamsResponse.ReadOnly =
    new Wrapper(impl)
}
